OpenSCM-Zenodo
==============

+----------------+--------------+--------+
|    |CI CD|     |  |Coverage|  | |Docs| |
+----------------+--------------+--------+

+------------------+----------------+------------------+
|  |PyPI Install|  |     |PyPI|     |  |PyPI Version|  |
+------------------+----------------+------------------+

+----------------+---------------+-----------+
| |Contributors| | |Last Commit| | |License| |
+----------------+---------------+-----------+

Brief summary
+++++++++++++

.. sec-begin-long-description
.. sec-begin-index

OpenSCM-Zenodo provides a basic command-line interface for creating new versions of Zenodo uploads and for uploading files to Zenodo.

.. sec-end-index

.. sec-begin-license

License
-------

OpenSCM-Zenodo is free software under a BSD 3-Clause License, see `LICENSE <https://github.com/openscm/openscm-zenodo/blob/master/LICENSE>`_.

.. sec-end-license
.. sec-end-long-description

.. sec-begin-installation

Installation
------------

OpenSCM-Zenodo can be installed with pip

.. code:: bash

    pip install openscm-zenodo

.. sec-end-installation

Documentation
-------------

Documentation can be found at our `documentation pages <https://openscm-zenodo.readthedocs.io/en/latest/>`_
(we are thankful to `Read the Docs <https://readthedocs.org/>`_ for hosting us).

Contributing
------------

Please see the `Development section of the docs <https://openscm-zenodo.readthedocs.io/en/latest/development.html>`_.

.. sec-begin-links

.. |CI CD| image:: https://github.com/openscm/openscm-zenodo/workflows/OpenSCM-Zenodo%20CI-CD/badge.svg
    :target: https://github.com/openscm/openscm-zenodo/actions?query=workflow%3A%22OpenSCM-Zenodo+CI-CD%22
.. |Coverage| image:: https://img.shields.io/codecov/c/github/openscm/openscm-zenodo.svg
    :target: https://codecov.io/gh/openscm/openscm-zenodo
.. |Docs| image:: https://readthedocs.org/projects/openscm-zenodo/badge/?version=latest
    :target: https://openscm-zenodo.readthedocs.io/en/latest
.. |PyPI Install| image:: https://github.com/openscm/openscm-zenodo/workflows/Test%20PyPI%20install/badge.svg
    :target: https://github.com/openscm/openscm-zenodo/actions?query=workflow%3A%22Test+PyPI+install%22
.. |PyPI| image:: https://img.shields.io/pypi/pyversions/openscm-zenodo.svg
    :target: https://pypi.org/project/openscm-zenodo/
.. |PyPI Version| image:: https://img.shields.io/pypi/v/openscm-zenodo.svg
    :target: https://pypi.org/project/openscm-zenodo/
.. |Contributors| image:: https://img.shields.io/github/contributors/openscm/openscm-zenodo.svg
    :target: https://github.com/openscm/openscm-zenodo/graphs/contributors
.. |Last Commit| image:: https://img.shields.io/github/last-commit/openscm/openscm-zenodo.svg
    :target: https://github.com/openscm/openscm-zenodo/commits/master
.. |License| image:: https://img.shields.io/github/license/openscm/openscm-zenodo.svg
    :target: https://github.com/openscm/openscm-zenodo/blob/master/LICENSE

.. sec-end-links
